Module: Codnar::Configuration

Includes:
Code, Comments, Documentation, Highlighting
Defined in:
lib/codnar/split_configurations.rb,
lib/codnar/configuration/code.rb,
lib/codnar/weave_configurations.rb,
lib/codnar/configuration/comments.rb,
lib/codnar/configuration/highlighting.rb,
lib/codnar/configuration/documentation.rb

Overview

A module for all the “built-in” configurations. The names of these configurations can be passed to the –require option of any Codnar Application.

Defined Under Namespace

Modules: Code, Comments, Documentation, Highlighting

Constant Summary collapse

WEAVE_INCLUDE =

Weave configuration providing a single simple include template.

{ "include" => "<%= chunk.expanded_html %>\n" }
WEAVE_PLAIN_CHUNK =

Weave chunks in the plainest possible way.

{
  "plain_chunk" => <<-EOF.unindent, #! ((( html
    <div class="plain chunk">
    <a name="<%= chunk.name.to_id %>"/>
    <%= chunk.expanded_html %>
    </div>
  EOF
}
WEAVE_NAMED_CHUNK_WITH_CONTAINERS =

Weave chunks with their name and the list of container chunks.

{
  "named_chunk_with_containers" => <<-EOF.unindent, #! ((( html
    <div class="named_with_containers chunk">
    <div class="chunk name">
    <a name="<%= chunk.name.to_id %>">
    <span><%= CGI.escapeHTML(chunk.name) %></span>
    </a>
    </div>
    <div class="chunk html">
    <%= chunk.expanded_html %>
    </div>
    % if chunk.containers != []
    <div class="chunk containers">
    <span class="chunk containers header">Contained in:</span>
    <ul class="chunk containers">
    % chunk.containers.each do |container|
    <li class="chunk container">
    <a class="chunk container" href="#<%= container.to_id %>"><%= CGI.escapeHTML(container) %></a>
    </li>
    % end
    </ul>
    </div>
    % end
    </div>
  EOF
}

Constants included from Highlighting

Highlighting::CHUNK_BY_VIM_REGIONS, Highlighting::FORMAT_CODE_CODERAY_CSS, Highlighting::FORMAT_CODE_CODERAY_HTML, Highlighting::FORMAT_CODE_GVIM_CSS, Highlighting::FORMAT_CODE_GVIM_HTML, Highlighting::FORMAT_CODE_SUNLIGHT

Constants included from Comments

Comments::CLASSIFY_CPP_COMMENTS, Comments::CLASSIFY_C_COMMENTS, Comments::CLASSIFY_DELIMITED_COMMENTS, Comments::CLASSIFY_DENOTED_COMMENTS, Comments::CLASSIFY_ELIXIR_COMMENTS, Comments::CLASSIFY_HADDOCK_COMMENTS, Comments::CLASSIFY_HTML_COMMENTS, Comments::CLASSIFY_SHELL_COMMENTS, Comments::CLASSIFY_SIMPLE_COMMENTS, Comments::FORMAT_HADDOCK_COMMENTS, Comments::FORMAT_MARKDOWN_COMMENTS, Comments::FORMAT_PRE_COMMENTS, Comments::FORMAT_RDOC_COMMENTS

Constants included from Code

Code::CLASSIFY_NESTED_CODE, Code::CLASSIFY_SOURCE_CODE

Constants included from Documentation

Documentation::SPLIT_GRAPHVIZ_DOCUMENTATION, Documentation::SPLIT_HTML_DOCUMENTATION, Documentation::SPLIT_MARKDOWN_DOCUMENTATION, Documentation::SPLIT_PRE_DOCUMENTATION, Documentation::SPLIT_RDOC_DOCUMENTATION

Method Summary

Methods included from Highlighting

klass_code_format, sunlight_code_format

Methods included from Comments

delimited_comments, denoted_comments, simple_comments