Module: Codnar::Rake
- Defined in:
- lib/codnar/rake.rb,
lib/codnar/rake/split_task.rb,
lib/codnar/rake/weave_task.rb
Overview
This module contains all the Codnar Rake tasks code.
Defined Under Namespace
Class Attribute Summary collapse
-
.chunk_files ⇒ Object
The list of split chunk files for later weaving.
-
.chunks_dir ⇒ Object
The root folder to store all chunk files under.
Class Method Summary collapse
-
.application_options(output, configurations) ⇒ Object
Compute options for invoking an application.
-
.configuration_files(configurations) ⇒ Object
Return the list of actual configuration files (as opposed to names of built-in configurations) for use as dependencies.
Class Attribute Details
.chunk_files ⇒ Object
The list of split chunk files for later weaving.
19 20 21 |
# File 'lib/codnar/rake.rb', line 19 def chunk_files @chunk_files end |
.chunks_dir ⇒ Object
The root folder to store all chunk files under.
16 17 18 |
# File 'lib/codnar/rake.rb', line 16 def chunks_dir @chunks_dir end |
Class Method Details
.application_options(output, configurations) ⇒ Object
Compute options for invoking an application.
27 28 29 30 31 |
# File 'lib/codnar/rake.rb', line 27 def self.(output, configurations) = [ "-o", output ] += configurations.map { |configuration| [ "-c", configuration.to_s ] }.flatten return end |
.configuration_files(configurations) ⇒ Object
Return the list of actual configuration files (as opposed to names of built-in configurations) for use as dependencies.
35 36 37 |
# File 'lib/codnar/rake.rb', line 35 def self.configuration_files(configurations) return configurations.find_all { |configuration| File.exists?(configuration.to_s) } end |