Class: Codnar::Rake::WeaveTask
- Inherits:
-
Rake::TaskLib
- Object
- Rake::TaskLib
- Codnar::Rake::WeaveTask
- Defined in:
- lib/codnar/rake/weave_task.rb
Overview
A Rake task for weaving chunks to a single HTML.
Instance Method Summary collapse
-
#initialize(root, configurations, output = "codnar.html") ⇒ WeaveTask
constructor
Create a Rake task for weaving chunks to a single HTML.
Constructor Details
#initialize(root, configurations, output = "codnar.html") ⇒ WeaveTask
Create a Rake task for weaving chunks to a single HTML. The root source file is expected to embed all the chunks into the output HTML. The chunks are loaded from the results of all the previous created SplitTask-s.
12 13 14 15 16 17 |
# File 'lib/codnar/rake/weave_task.rb', line 12 def initialize(root, configurations, output = "codnar.html") @root = Rake.chunks_dir + "/" + root @output = output @configurations = configurations define_tasks end |